@@ -1,7 +1,7 @@
 /*
  * This file is part of MapWidget
  *
- * Copyright (C) 2007 Pekka Rönkkö (pronkko@gmail.com).
+ * Copyright (C) 2007 Pekka Rönkkö (pronkko@gmail.com), Kai Skiftesvik
  *
  * Part of code is ripped from John Costigan's Maemo Mapper.
  *
@@ -38,9 +38,9 @@ static void map_widget_do_callbacks_first(GtkWidget *dmap);
 static void map_widget_do_callbacks_second(GtkWidget *dmap);
 static void map_widget_do_callbacks_third(GtkWidget *dmap);
 
-const gchar * MAP_WIDGET_FW_DBUS_SERVICE = "org.cityguide.maptileloader";
-const gchar * MAP_WIDGET_FW_DBUS_OBJECT_PATH = "/org/cityguide/maptileloader";
-const gchar * MAP_WIDGET_FW_DBUS_INTERFACE = "org.cityguide.maptileloader";
+const gchar * MAP_WIDGET_FW_DBUS_SERVICE = "org.ecoach.maptileloader";
+const gchar * MAP_WIDGET_FW_DBUS_OBJECT_PATH = "/org/ecoach/maptileloader";
+const gchar * MAP_WIDGET_FW_DBUS_INTERFACE = "org.ecoach.maptileloader";
 const gchar * MAP_WIDGET_FW_FUNCTION_MAPTILE_REQUEST = "MaptileLoaderGetMaptile";
 const gchar * MAP_WIDGET_FW_FUNCTION_GET_SUPPORTED_MAPS = "MaptileLoaderGetSupportedMaps";
 const gchar * MAP_WIDGET_FW_FUNCTION_SET_REPOFILE = "MaptileLoaderSetRepofile";
@@ -1285,10 +1285,10 @@ void map_widget_draw_current_place(GtkWidget *dmap)
 	   	 gdk_draw_arc(	dmap->window,
 			get_color(dmap,COLOR_RED),
 			FALSE, 
-			mark_x1,
-			mark_y1,
-        		3, 
-			3,
+			mark_x1-10,
+			mark_y1-10,
+        		20,
+			20,
         		0, 
 			360 * 64);
 	}
